@@ -776,17 +776,22 @@ sub create_class {
     my $maxid = $dbh->selectrow_array
         ('SELECT MAX(classid) FROM class WHERE dmid = ?', undef, $dmid) || 0;
 
+    my $clsid = $maxid + 1;
+    if ($classname eq 'default') {
+        $clsid = 0;
+    }
+
     # now insert the new class
     my $rv = eval {
         $dbh->do("INSERT INTO class (dmid, classid, classname, mindevcount) VALUES (?, ?, ?, ?)",
-                 undef, $dmid, $maxid + 1, $classname, 2);
+                 undef, $dmid, $clsid, $classname, 2);
     };
     if ($@ || $dbh->err) {
         if ($self->was_duplicate_error) {
             throw("dup");
         }
     }
-    return $maxid + 1 if $rv;
+    return $clsid if $rv;
     $self->condthrow;
     die;
 }
@@ -964,8 +969,11 @@ sub register_tempfile {
         return $exists ? 1 : 0;
     };
 
+    # See notes in MogileFS::Config->check_database
+    my $min_fidid = MogileFS::Config->config('min_fidid');
+
     # if the fid is in use, do something
-    while ($fid_in_use->($fid)) {
+    while ($fid_in_use->($fid) || $fid <= $min_fidid) {
         throw("dup") if $explicit_fid_used;
 
         # be careful of databases which reset their
