@@ -10,6 +10,7 @@ use fields (
             );
 use MogileFS::Util qw(every error debug);
 use MogileFS::Config;
+use MogileFS::Server;
 use List::Util ();
 use Time::HiRes ();
 
@@ -256,7 +257,7 @@ sub parallel_check_sizes {
 use constant CANT_FIX => 0;
 sub fix_fid {
     my ($self, $fid) = @_;
-    debug(sprintf("Fixing FID %d\n", $fid->id));
+    debug(sprintf("Fixing FID %d", $fid->id));
 
     # This should happen first, since the fid gets awkwardly reloaded...
     $fid->update_devcount;
